@@ -35,16 +35,27 @@ sub connect {
 
 sub get {
     my $self = shift;
-    my $key  = shift;
+    return $self->_retrieve('get', shift);
+}
+
+sub gets {
+    my $self = shift;
+    return $self->_retrieve('gets', shift);
+}
+
+sub _retrieve {
+    my $self = shift;
+    my ($cmd, $key) = @_;
 
     my $socket = $self->{socket};
-    print $socket "get $key\r\n";
+    print $socket "$cmd $key\r\n";
 
     my %data = (key => $key);
     my $response = <$socket>;
-    if ($response =~ m/^VALUE \S+ (\d+) (\d+)/) {
+    if ($response =~ m/^VALUE \S+ (\d+) (\d+)(?: (\d+))?/) {
         $data{flags}  = $1;
         $data{length} = $2;
+        $data{cas}    = $3;
         read $socket, $response, $data{length};
         $data{value} = $response;
 
@@ -95,6 +106,31 @@ sub _store {
     return 1;
 }
 
+sub cas {
+    my $self   = shift;
+    my $key    = shift;
+    my $value  = shift;
+    my $cas    = shift;
+    my %option = @_;
+
+    my $flags  = $option{flags}  || 0;
+    my $expire = $option{expire} || 0;
+    my $bytes  = sub {
+        use bytes;
+        return length $value;
+    }->();
+
+    my $socket = $self->{socket};
+    print $socket "cas $key $flags $expire $bytes $cas\r\n";
+    print $socket "$value\r\n";
+    my $response = $self->_readline;
+    if ($response !~ m/^STORED/) {
+        debug qq{Failed to set data as ($key, $value) with cas $cas};
+        return;
+    }
+    return 1;
+}
+
 sub delete {
     my $self = shift;
     my $key  = shift;
