@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008_001;
 
-use version; our $VERSION = 'v0.6.1';
+use version; our $VERSION = 'v0.6.2';
 
 our @COMMANDS_INFO = (
     +{
@@ -82,6 +82,14 @@ EODESC
         description => <<'EODESC',
 Usage:
     > get <KEY>
+EODESC
+    },
+    +{
+        command => 'gets',
+        summary => 'Get data by KEY with cas',
+        description => <<'EODESC',
+Usage:
+    > gets <KEY>
 EODESC
     },
     +{
@@ -145,6 +153,20 @@ Description:
 Usage:
     > prepend <KEY> <VALUE>
     > prepend mykey MyPrefix
+EODESC
+    },
+    +{
+        command => 'cas',
+        summary => 'Set data by KEY VALUE with CAS',
+        description => <<'EODESC',
+Description:
+    Store data as specified (KEY, VALUE) if CAS of data is not modified.
+
+Usage:
+    > cas <KEY> <VALUE> <CAS> [<EXPIRE> [<FLAGS>]]
+    > cas mykey1 MyValue1 1
+    > cas mykey2 MyValue2 26  0     # Never expires. Default
+    > cas mykey3 MyValue3 355 120 1
 EODESC
     },
     +{
