@@ -6,7 +6,7 @@ use 5.008_001;
 
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.6.1';
+use version; our $VERSION = 'v0.6.2';
 
 my $DISPLAY_DATA_LENGTH = 320;
 
@@ -16,12 +16,14 @@ sub new {
     bless \%data, $class;
 }
 
-sub find_by_get {
+sub find {
     my $class = shift;
     my $key   = shift;
     my $ds    = shift;
+    my %opt   = @_;
 
-    my $data = $ds->get($key);
+    my $command = $opt{command} || 'get';
+    my $data    = $ds->$command($key);
     return unless $data->{value};
 
     bless $data, $class;
@@ -41,9 +43,11 @@ sub save {
     );
 
     my $command = $opt{command} || 'set';
-    my $ret = $ds->$command($self->{key}, $self->{value}, %option);
-
-    return $ret;
+    if ($command eq 'cas') {
+        return $ds->$command(@$self{qw/key value cas/}, %option);
+    } else {
+        return $ds->$command(@$self{qw/key value/}, %option);
+    }
 }
 
 sub remove {
@@ -57,11 +61,12 @@ sub output {
     my $self = shift;
     my $space = q{ } x 4;
     my %method = (value => 'disp_value');
-    for my $key (qw/key value flags length/) {
+    for my $key (qw/key value flags length cas/) {
         my $value = $self->{$key};
         if (my $_method = $method{$key}) {
             $value = $self->$_method;
         }
+        next unless defined $value;
         printf "%s%6s:%s%s\n", $space, $key, $space, $value;
     }
 }
