@@ -17,7 +17,7 @@ use App::Memcached::CLI::Help;
 use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.6.1';
+use version; our $VERSION = 'v0.6.2';
 
 my $PROGRAM = basename $0;
 
@@ -32,11 +32,13 @@ my %COMMAND2ALIASES = (
     detaildump => [qw(\dd)],
     detail     => [],
     get        => [],
+    gets       => [],
     set        => [],
     add        => [],
     replace    => [],
     append     => [],
     prepend    => [],
+    cas        => [],
     delete     => [],
     flush_all  => [qw(flush)],
 );
@@ -218,12 +220,24 @@ sub _sorted_aliases_of {
 
 sub get {
     my $self = shift;
-    my $key  = shift;
+    return $self->_retrieve('get', shift);
+}
+
+sub gets {
+    my $self = shift;
+    return $self->_retrieve('gets', shift);
+}
+
+sub _retrieve {
+    my $self = shift;
+    my ($command, $key) = @_;
     unless ($key) {
         print "No KEY specified.\n";
         return;
     }
-    my $item = App::Memcached::CLI::Item->find_by_get($key, $self->{ds});
+    my $item = App::Memcached::CLI::Item->find(
+        $key, $self->{ds}, command => $command,
+    );
     unless ($item) {
         print "Not found - $key\n";
     } else {
@@ -260,6 +274,28 @@ sub _store {
     return 1;
 }
 
+sub cas {
+    my $self = shift;
+    my ($key, $value, $cas, $expire, $flags) = @_;
+    unless ($key and $value and $cas) {
+        print "KEY or VALUE or CAS not specified.\n";
+        return;
+    }
+    my $item = App::Memcached::CLI::Item->new(
+        key    => $key,
+        value  => $value,
+        expire => $expire,
+        flags  => $flags,
+        cas    => $cas,
+    );
+    unless ($item->save($self->{ds}, command => 'cas')) {
+        print "Failed to cas item. KEY $key, VALUE $value\n";
+        return 1;
+    }
+    print "OK\n";
+    return 1;
+}
+
 sub delete {
     my $self = shift;
     my $key  = shift;
